==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/ko.js <==
﻿/*
 * PLUGIN RSS
 *
 * Korean language file.
 *
 * Author: Limerainne (limerainne@gmail.com)
 */

 theUILang.addRSS			= "RSS 피드 추가";
 theUILang.feedURL			= "피드 URL";
 theUILang.alias			= "별명";
 theUILang.rssAuto			= "피드에 발행된 항목 알아서 다운로드";
 theUILang.allFeeds			= "모든 피드";
 theUILang.incorrectURL 		= "올바른 피드 URL을 지정해주세요."
 theUILang.cantFetchRSS 		= "피드를 불러오지 못했습니다.";
 theUILang.rssAlreadyExist		= "피드가 이미 등록되어 있습니다.";
 theUILang.rssDontExist 		= "피드가 존재하지 않습니다.";
 theUILang.rssCantLoadTorrent		= "토렌트를 불러오지 못했습니다.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "이미 불러옮";
 theUILang.rssMenuLoad			= "불러오기";
 theUILang.rssMenuOpen			= "브라우저에서 열기";
 theUILang.rssMenuClearHistory		= "기록 지우기";
 theUILang.rssMenuAddToFilter		= "즐겨찾기에 추가";
 theUILang.rssMenuManager		= "RSS 관리자";
 theUILang.rssMenuRefresh		= "피드 업데이트";
 theUILang.rssMenuDisable		= "피드 비활성화";
 theUILang.rssMenuEnable		= "피드 활성화";
 theUILang.rssMenuEdit			= "피드 편집";
 theUILang.rssMenuDelete		= "피드 제거";
 theUILang.rssDeletePrompt		= "정말 선택한 피드를 제거할까요?";
 theUILang.rssNewFilter 		= "새 필터";
 theUILang.rssFilter			= "필터";
 theUILang.rssAddFilter 		= "추가";
 theUILang.rssDelFilter 		= "삭제";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "필터 설정";
 theUILang.rssIncorrectFilter		= "필터가 잘못되었습니다.";
 theUILang.foundedByFilter		= "일치";
 theUILang.rssExclude			= "제외";
 theUILang.rssStatusError		= "불러오기 오류";
 theUILang.rssFeeds			= "피드";
 theUILang.rssCheckTitle		= "제목 열 검사";
 theUILang.rssCheckDescription		= "설명 열 검사";
 theUILang.rssCheckLink 		= "링크 주소 열 검사";
 theUILang.rssMinInterval		= "최소 간격";
 theUILang.rssIntervalAlways		= "(항상 검사)";
 theUILang.rssIntervalOnce		= "(한번만 검사)";
 theUILang.rssInterval12h		= "12 시간";
 theUILang.rssInterval1d		= "1 일";
 theUILang.rssInterval2d		= "2 일";
 theUILang.rssInterval3d		= "3 일";
 theUILang.rssInterval4d		= "4 일";
 theUILang.rssInterval6d		= "6 일";
 theUILang.rssInterval1w		= "1 주";
 theUILang.rssInterval2w		= "2 주";
 theUILang.rssInterval3w		= "3 주";
 theUILang.rssInterval1m		= "1 달";
 theUILang.rssClearFilter		= "초기화";
 theUILang.rssMarkAs			= "다음 상태로 표기";
 theUILang.rssAsLoaded			= "불러옮";
 theUILang.rssAsUnloaded		= "불러오지 않음";
 theUILang.addRSSGroup			= "RSS 그룹 추가";
 theUILang.editRSSGroup 		= "RSS 그룹 편집";
 theUILang.addRSSGroupContent		= "항목";
 theUILang.rssMenuGroupDisable		= "그룹 비활성화";
 theUILang.rssMenuGroupRefresh		= "그룹 업데이트";
 theUILang.rssMenuGroupEnable		= "그룹 활성화";
 theUILang.rssMenuGroupEdit		= "그룹 편집";
 theUILang.rssMenuGroupDelete		= "그룹 제거";
 theUILang.rssMenuGroupContentsDelete	= "항목 제거";
 theUILang.rssDeleteGroupPrompt 	= "정말 선택한 그룹을 제거할까요?";
 theUILang.rssDeleteGroupContentsPrompt = "정말 선택한 그룹 및 모든 항목을 제거할까요?";
 theUILang.rssAllFiters 		= "모든 필터";
 theUILang.rssUpdateInterval 		= "업데이트 주기";
 theUILang.Directories			= "디렉토리";
 theUILang.Labels			= "라벨";

thePlugins.get("rss").langLoaded();

==> rutorrent-4.3.5.tar.gz: ruTorrent-4.3.5/plugins/rss/lang/ko.js <==
﻿/*
 * PLUGIN RSS
 *
 * Korean language file.
 *
 * Author: Limerainne (limerainne@gmail.com)
 */

 theUILang.addRSS			= "RSS 피드 추가";
 theUILang.feedURL			= "피드 URL";
 theUILang.alias			= "별명";
 theUILang.rssAuto			= "피드에 발행된 항목 알아서 다운로드";
 theUILang.allFeeds			= "모든 피드";
 theUILang.incorrectURL			= "올바른 피드 URL을 지정해주세요.";
 theUILang.cantFetchRSS			= "피드를 불러오지 못했습니다.";
 theUILang.rssAlreadyExist		= "피드가 이미 등록되어 있습니다.";
 theUILang.rssDontExist			= "피드가 존재하지 않습니다.";
 theUILang.rssCantLoadTorrent		= "토렌트를 불러오지 못했습니다.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "이미 불러옮";
 theUILang.rssMenuLoad			= "불러오기";
 theUILang.rssMenuOpen			= "브라우저에서 열기";
 theUILang.rssMenuClearHistory		= "기록 지우기";
 theUILang.rssMenuAddToFilter		= "즐겨찾기에 추가";
 theUILang.rssMenuManager		= "RSS 관리자";
 theUILang.rssMenuRefresh		= "피드 업데이트";
 theUILang.rssMenuDisable		= "피드 비활성화";
 theUILang.rssMenuEnable		= "피드 활성화";
 theUILang.rssMenuEdit			= "피드 편집";
 theUILang.rssMenuDelete		= "피드 제거";
 theUILang.rssDeletePrompt		= "정말 선택한 피드를 제거할까요?";
 theUILang.rssNewFilter			= "새 필터";
 theUILang.rssFilter			= "필터";
 theUILang.rssAddFilter			= "추가";
 theUILang.rssDelFilter			= "삭제";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "필터 설정";
 theUILang.rssIncorrectFilter		= "필터가 잘못되었습니다.";
 theUILang.foundedByFilter		= "일치";
 theUILang.rssExclude			= "제외";
 theUILang.rssStatusError		= "불러오기 오류";
 theUILang.rssFeeds			= "피드";
 theUILang.rssCheckTitle		= "제목 열 검사";
 theUILang.rssCheckDescription		= "설명 열 검사";
 theUILang.rssCheckLink			= "링크 주소 열 검사";
 theUILang.rssMinInterval		= "최소 간격";
 theUILang.rssIntervalAlways		= "(항상 검사)";
 theUILang.rssIntervalOnce		= "(한번만 검사)";
 theUILang.rssInterval12h		= "12 시간";
 theUILang.rssInterval1d		= "1 일";
 theUILang.rssInterval2d		= "2 일";
 theUILang.rssInterval3d		= "3 일";
 theUILang.rssInterval4d		= "4 일";
 theUILang.rssInterval6d		= "6 일";
 theUILang.rssInterval1w		= "1 주";
 theUILang.rssInterval2w		= "2 주";
 theUILang.rssInterval3w		= "3 주";
 theUILang.rssInterval1m		= "1 달";
 theUILang.rssClearFilter		= "초기화";
 theUILang.rssMarkAs			= "다음 상태로 표기";
 theUILang.rssAsLoaded			= "불러옮";
 theUILang.rssAsUnloaded		= "불러오지 않음";
 theUILang.addRSSGroup			= "RSS 그룹 추가";
 theUILang.editRSSGroup			= "RSS 그룹 편집";
 theUILang.addRSSGroupContent		= "항목";
 theUILang.rssMenuGroupDisable		= "그룹 비활성화";
 theUILang.rssMenuGroupRefresh		= "그룹 업데이트";
 theUILang.rssMenuGroupEnable		= "그룹 활성화";
 theUILang.rssMenuGroupEdit		= "그룹 편집";
 theUILang.rssMenuGroupDelete		= "그룹 제거";
 theUILang.rssMenuGroupContentsDelete	= "항목 제거";
 theUILang.rssDeleteGroupPrompt		= "정말 선택한 그룹을 제거할까요?";
 theUILang.rssDeleteGroupContentsPrompt	= "정말 선택한 그룹 및 모든 항목을 제거할까요?";
 theUILang.rssAllFiters			= "모든 필터";
 theUILang.rssUpdateInterval		= "업데이트 주기";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "디렉토리";
 theUILang.Labels			= "라벨";

thePlugins.get("rss").langLoaded();
